trame-components: trame vue.js widgets
===========================================================================

trame-components extend trame **widgets** with helper components that are core to trame widgets.

This package is not supposed to be used by iteself but rather should come as a dependency of **trame**.
For any specificity, please refer to `the trame documentation <https://kitware.github.io/trame/>`_.


Installing
-----------------------------------------------------------

trame-components can be installed with `pip <https://pypi.org/project/trame-components/>`_:

.. code-block:: bash

    pip install --upgrade trame-components


Usage
-----------------------------------------------------------

The `Trame Tutorial <https://kitware.github.io/trame/docs/tutorial.html>`_ is the place to go to learn how to use the library and start building your own application.

The `API Reference <https://trame.readthedocs.io/en/latest/index.html>`_ documentation provides API-level documentation.

This library specifically brings the following set of vue.js components to the core trame package.

.. code-block:: html

    <ClientStateChange  ... />
    <ClientTriggers     ... />
    <FloatCard          ... />
    <GitTree .          .. />
    <LifeCycleMonitor   ... />
    <ListBrowser        ... />
    <MouseTrap          ... />
    <SizeObserver       ... />
    <XaiHeatMap         ... />
    <XaiImage           ... />


License
-----------------------------------------------------------

trame-client is made available under the Apache License, Version 2.0. For more details, see `LICENSE <https://github.com/Kitware/trame-components/blob/master/LICENSE>`_


Community
-----------------------------------------------------------

`Trame <https://kitware.github.io/trame/>`_ | `Discussions <https://github.com/Kitware/trame/discussions>`_ | `Issues <https://github.com/Kitware/trame/issues>`_ | `RoadMap <https://github.com/Kitware/trame/projects/1>`_ | `Contact Us <https://www.kitware.com/contact-us/>`_

.. image:: https://zenodo.org/badge/410108340.svg
    :target: https://zenodo.org/badge/latestdoi/410108340


Enjoying trame?
-----------------------------------------------------------

Share your experience `with a testimonial <https://github.com/Kitware/trame/issues/18>`_ or `with a brand approval <https://github.com/Kitware/trame/issues/19>`_.
